interactive_viewer_plus library

Classes

InteractiveViewerPlus
InteractiveViewerPlus is a drop in replacement and enhanced version of Flutter's InteractiveViewer that adds support for pan, zoom, and rotation, flip and improved programmatic control through InteractiveViewerPlusController.
InteractiveViewerPlusController
A controller for InteractiveViewerPlus that manages the transformation matrix and provides programmatic control over pan, zoom, and rotation.

Enums

GestureType